from steam.enums import EResult
from dota2.enums import EDOTAGCMsg

class Player(object):
    def __init__(self):
        super(Player, self).__init__()

        # register our handlers
        self.on(EDOTAGCMsg.EMsgGCPlayerInfo, self.__handle_player_info)
        self.on(EDOTAGCMsg.EMsgClientToGCLatestConductScorecard, self.__handle_conduct_scorecard)
        self.on(EDOTAGCMsg.EMsgGCGetHeroStandingsResponse, self.__handle_hero_standings)

    def request_profile(self, account_id, request_name=False):
        """
        Request profile details

        .. warning::

            This is disabled by Valve

        :param account_id: steam account_id
        :type account_id: :class:`int`
        :param request_name: whether to return name
        :type request_name: :class:`bool`
        :return: job id
        :rtype: :class:`str`

        Response event: ``profile_data``

        :param account_id: account_id from request
        :type account_id: :class:`int`
        :param eresult: result enum
        :type eresult: :class:`steam.enums.EResult`
        :param message: `CMsgDOTAProfileResponse <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L282-L323>`_
        :type  message: proto message

        """
        jobid = self.send_job(EDOTAGCMsg.EMsgGCProfileRequest, {
                              'account_id': account_id,
                              'request_name': request_name,
                              })

        def wrap_profile_data(message):
            eresult = EResult(message.result)
            message = message if eresult == EResult.OK else None
            self.emit("profile_data", account_id, eresult, message)

        self.once(jobid, wrap_profile_data)

        return jobid

    def request_profile_card(self, account_id):
        """
        Request profile card

        :param account_id: steam account_id
        :type account_id: :class:`int`
        :return: job id
        :rtype: :class:`str`

        Response event: ``profile_card``

        :param account_id: account_id from request
        :type account_id: :class:`int`
        :param message: `CMsgDOTAProfileCard <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_common.proto#L375-L426>`_
        :type  message: proto message

        """
        jobid = self.send_job(EDOTAGCMsg.EMsgClientToGCGetProfileCard, {
                              'account_id': account_id,
                              })

        def wrap_profile_card(message):
            self.emit("profile_card", account_id, message)

        self.once(jobid, wrap_profile_card)

        return jobid

    def request_player_stats(self, account_id):
        """
        Request players stats. These are located in the ``play style`` box on a player profie.

        :param account_id: steam account_id
        :type account_id: :class:`int`
        :return: job id
        :rtype: :class:`str`

        Response event: ``player_stats``

        :param account_id: account_id from request
        :type account_id: :class:`int`
        :param message: `CMsgGCToClientPlayerStatsResponse <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L1159-L1179>`_
        :type  message: proto message

        """
        jobid = self.send_job(EDOTAGCMsg.EMsgClientToGCPlayerStatsRequest, {
                              'account_id': account_id,
                              })

        def wrap_player_stats(message):
            self.emit("player_stats", account_id, message)

        self.once(jobid, wrap_player_stats)

        return jobid

    def request_player_info(self, account_ids):
        """
        Request official player information

        :param account_id: A list of account ids
        :type account_id: :class:`list`

        Response event: ``player_info``

        :param message: `CMsgGCPlayerInfo <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client_fantasy.proto#L106-L129>`_
        :type  message: proto message
        """
        if not isinstance(account_ids, list):
            raise ValueError("Expected account_ids to be a list")

        self.send(EDOTAGCMsg.EMsgGCPlayerInfoRequest, {
                  'player_infos': map(lambda x: {'account_id': x}, account_ids),
                  })

    def __handle_player_info(self, message):
        self.emit("player_info", message)

    def request_conduct_scorecard(self):
        """
        Request conduct scorecard, otherwise knows as conduct summary

        :return: job id
        :rtype: :class:`str`

        Response event: ``conduct_scorecard``

        :param message: `CMsgPlayerConductScorecard <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L1415-L1429>`_
        :type  message: proto message
        """
        return self.send_job(EDOTAGCMsg.EMsgClientToGCLatestConductScorecardRequest)

    def __handle_conduct_scorecard(self, message):
        self.emit("conduct_scorecard", message)

    def request_hero_standings(self):
        """
        Request hero stands for the currently logged on account.
        This is the data from the ``stats`` tab on your profile.

        Response event: ``hero_standings``

        :param message: `CMsgGCGetHeroStandingsResponse <https://github.com/ValvePython/dota2/blob/e06c81c03579a912fcca829766ee590075ae97dc/protobufs/dota_gcmessages_client.proto#L721-L741>`_
        :type  message: proto message
        """
        return self.send_job(EDOTAGCMsg.EMsgGCGetHeroStandings)

    def __handle_hero_standings(self, message):
        self.emit("hero_standings", message)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: dota_gcmessages_client_guild.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
from google.protobuf import descriptor_pb2
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor.FileDescriptor(
  name='dota_gcmessages_client_guild.proto',
  package='',
  syntax='proto2',
  serialized_pb=_b('\n\"dota_gcmessages_client_guild.proto\"\xb8\x03\n\x10\x43MsgDOTAGuildSDO\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0b\n\x03tag\x18\x03 \x01(\t\x12\x14\n\x0ctime_created\x18\x04 \x01(\r\x12\x16\n\x0etime_disbanded\x18\x05 \x01(\r\x12\x0c\n\x04logo\x18\x06 \x01(\x04\x12\x11\n\tbase_logo\x18\x07 \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\x08 \x01(\x04\x12)\n\x07members\x18\t \x03(\x0b\x32\x18.CMsgDOTAGuildSDO.Member\x12\x31\n\x0binvitations\x18\n \x03(\x0b\x32\x1c.CMsgDOTAGuildSDO.Invitation\x12\x0f\n\x07message\x18\x0b \x01(\t\x12\x13\n\x0bincremental\x18\x0c \x01(\x08\x1a?\n\x06Member\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x13\n\x0btime_joined\x18\x02 \x01(\r\x12\x0c\n\x04role\x18\x03 \x01(\r\x1aN\n\nInvitation\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x11\n\ttime_sent\x18\x02 \x01(\r\x12\x19\n\x11\x61\x63\x63ount_id_sender\x18\x03 \x01(\r\"\x87\x02\n\x15\x43MsgDOTAGuildAuditSDO\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12-\n\x07\x65ntries\x18\x02 \x03(\x0b\x32\x1c.CMsgDOTAGuildAuditSDO.Entry\x1a\xac\x01\n\x05\x45ntry\x12\x13\n\x0b\x65vent_index\x18\x01 \x01(\r\x12\x11\n\ttimestamp\x18\x02 \x01(\r\x12\x0e\n\x06\x61\x63tion\x18\x03 \x01(\r\x12\x1c\n\x14\x61\x63\x63ount_id_requestor\x18\x04 \x01(\r\x12\x19\n\x11\x61\x63\x63ount_id_target\x18\x05 \x01(\r\x12\x18\n\x10reference_data_a\x18\x06 \x01(\r\x12\x18\n\x10reference_data_b\x18\x07 \x01(\r\"\xbe\x02\n\"CMsgDOTAAccountGuildMembershipsSDO\x12\x12\n\naccount_id\x18\x01 \x01(\r\x12\x43\n\x0bmemberships\x18\x02 \x03(\x0b\x32..CMsgDOTAAccountGuildMembershipsSDO.Membership\x12\x43\n\x0binvitations\x18\x03 \x03(\x0b\x32..CMsgDOTAAccountGuildMembershipsSDO.Invitation\x1a,\n\nMembership\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x0c\n\x04role\x18\x02 \x01(\r\x1aL\n\nInvitation\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x11\n\ttime_sent\x18\x02 \x01(\r\x12\x19\n\x11\x61\x63\x63ount_id_sender\x18\x03 \x01(\r\"m\n\x1a\x43MsgDOTAGuildCreateRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0b\n\x03tag\x18\x02 \x01(\t\x12\x0c\n\x04logo\x18\x03 \x01(\x04\x12\x11\n\tbase_logo\x18\x04 \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\x05 \x01(\x04\"\xba\x02\n\x1b\x43MsgDOTAGuildCreateResponse\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x33\n\x06\x65rrors\x18\x02 \x03(\x0e\x32#.CMsgDOTAGuildCreateResponse.EError\"\xd3\x01\n\x06\x45\x45rror\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0e\n\nNAME_EMPTY\x10\x01\x12\x17\n\x13NAME_BAD_CHARACTERS\x10\x02\x12\x11\n\rNAME_TOO_LONG\x10\x03\x12\x0e\n\nNAME_TAKEN\x10\x04\x12\r\n\tTAG_EMPTY\x10\x05\x12\x16\n\x12TAG_BAD_CHARACTERS\x10\x06\x12\x10\n\x0cTAG_TOO_LONG\x10\x07\x12\x1b\n\x17\x41\x43\x43OUNT_TOO_MANY_GUILDS\x10\x08\x12\x16\n\x12LOGO_UPLOAD_FAILED\x10\t\"f\n\"CMsgDOTAGuildSetAccountRoleRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x19\n\x11target_account_id\x18\x02 \x01(\r\x12\x13\n\x0btarget_role\x18\x03 \x01(\r\"\x95\x02\n#CMsgDOTAGuildSetAccountRoleResponse\x12\x45\n\x06result\x18\x01 \x01(\x0e\x32,.CMsgDOTAGuildSetAccountRoleResponse.EResult:\x07SUCCESS\"\xa6\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12\x19\n\x15\x45RROR_NO_OTHER_LEADER\x10\x03\x12!\n\x1d\x45RROR_ACCOUNT_TOO_MANY_GUILDS\x10\x04\x12 \n\x1c\x45RROR_GUILD_TOO_MANY_MEMBERS\x10\x05\"P\n!CMsgDOTAGuildInviteAccountRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x19\n\x11target_account_id\x18\x02 \x01(\r\"\xe3\x02\n\"CMsgDOTAGuildInviteAccountResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAGuildInviteAccountResponse.EResult:\x07SUCCESS\"\xf6\x01\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\x12!\n\x1d\x45RROR_ACCOUNT_ALREADY_INVITED\x10\x03\x12\"\n\x1e\x45RROR_ACCOUNT_ALREADY_IN_GUILD\x10\x04\x12\"\n\x1e\x45RROR_ACCOUNT_TOO_MANY_INVITES\x10\x05\x12 \n\x1c\x45RROR_GUILD_TOO_MANY_INVITES\x10\x06\x12!\n\x1d\x45RROR_ACCOUNT_TOO_MANY_GUILDS\x10\x07\"O\n CMsgDOTAGuildCancelInviteRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x19\n\x11target_account_id\x18\x02 \x01(\r\"\xb0\x01\n!CMsgDOTAGuildCancelInviteResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAGuildCancelInviteResponse.EResult:\x07SUCCESS\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"k\n!CMsgDOTAGuildUpdateDetailsRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x0c\n\x04logo\x18\x02 \x01(\x04\x12\x11\n\tbase_logo\x18\x03 \x01(\x04\x12\x13\n\x0b\x62\x61nner_logo\x18\x04 \x01(\x04\"\xb2\x01\n\"CMsgDOTAGuildUpdateDetailsResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAGuildUpdateDetailsResponse.EResult:\x07SUCCESS\"F\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\x12\x17\n\x13\x45RROR_NO_PERMISSION\x10\x02\"\x80\x01\n)CMsgDOTAGCToGCUpdateOpenGuildPartyRequest\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x10\n\x08guild_id\x18\x02 \x01(\r\x12\x1a\n\x12member_account_ids\x18\x03 \x03(\r\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"J\n*CMsgDOTAGCToGCUpdateOpenGuildPartyResponse\x12\x1c\n\x14maintain_association\x18\x01 \x01(\x08\"P\n*CMsgDOTAGCToGCDestroyOpenGuildPartyRequest\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x10\n\x08guild_id\x18\x02 \x01(\r\"-\n+CMsgDOTAGCToGCDestroyOpenGuildPartyResponse\"I\n CMsgDOTAPartySetOpenGuildRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"\x97\x01\n!CMsgDOTAPartySetOpenGuildResponse\x12\x43\n\x06result\x18\x01 \x01(\x0e\x32*.CMsgDOTAPartySetOpenGuildResponse.EResult:\x07SUCCESS\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"5\n!CMsgDOTAJoinOpenGuildPartyRequest\x12\x10\n\x08party_id\x18\x01 \x01(\x04\"\x99\x01\n\"CMsgDOTAJoinOpenGuildPartyResponse\x12\x44\n\x06result\x18\x01 \x01(\x0e\x32+.CMsgDOTAJoinOpenGuildPartyResponse.EResult:\x07SUCCESS\"-\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x15\n\x11\x45RROR_UNSPECIFIED\x10\x01\"\xd7\x01\n\x1d\x43MsgDOTAGuildOpenPartyRefresh\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12>\n\x0copen_parties\x18\x02 \x03(\x0b\x32(.CMsgDOTAGuildOpenPartyRefresh.OpenParty\x1a\x64\n\tOpenParty\x12\x10\n\x08party_id\x18\x01 \x01(\x04\x12\x1a\n\x12member_account_ids\x18\x02 \x03(\r\x12\x14\n\x0ctime_created\x18\x03 \x01(\r\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\"\x1a\n\x18\x43MsgDOTARequestGuildData\"\xb7\x01\n\x17\x43MsgDOTAGuildInviteData\x12\x18\n\x10invited_to_guild\x18\x01 \x01(\x08\x12\x10\n\x08guild_id\x18\x02 \x01(\r\x12\x12\n\nguild_name\x18\x03 \x01(\t\x12\x11\n\tguild_tag\x18\x04 \x01(\t\x12\x0c\n\x04logo\x18\x05 \x01(\x04\x12\x0f\n\x07inviter\x18\x06 \x01(\r\x12\x14\n\x0cinviter_name\x18\x07 \x01(\t\x12\x14\n\x0cmember_count\x18\x08 \x01(\r\"?\n\x1a\x43MsgDOTAGuildUpdateMessage\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x10\n\x08guild_id\x18\x02 \x01(\r\">\n\x1c\x43MsgDOTAGuildEditLogoRequest\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12\x0c\n\x04logo\x18\x02 \x01(\x04\"\xcc\x01\n\x1d\x43MsgDOTAGuildEditLogoResponse\x12\x10\n\x08guild_id\x18\x01 \x01(\r\x12?\n\x06result\x18\x02 \x01(\x0e\x32&.CMsgDOTAGuildEditLogoResponse.EResult:\x07SUCCESS\"X\n\x07\x45Result\x12\x0b\n\x07SUCCESS\x10\x00\x12\x11\n\rNO_PERMISSION\x10\x01\x12\x16\n\x12LOGO_UPLOAD_FAILED\x10\x02\x12\x15\n\x11UNSPECIFIED_ERROR\x10\x03\x42\x05H\x01\x90\x01\x00')
)
_sym_db.RegisterFileDescriptor(DESCRIPTOR)



_CMSGDOTAGUILDCREATERESPONSE_EERROR = _descriptor.EnumDescriptor(
  name='EError',
  full_name='CMsgDOTAGuildCreateResponse.EError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_EMPTY', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_BAD_CHARACTERS', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TOO_LONG', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NAME_TAKEN', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_EMPTY', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_BAD_CHARACTERS', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TAG_TOO_LONG', index=7, number=7,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ACCOUNT_TOO_MANY_GUILDS', index=8, number=8,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGO_UPLOAD_FAILED', index=9, number=9,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1283,
  serialized_end=1494,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDCREATERESPONSE_EERROR)

_CMSGDOTAGUILDSETACCOUNTROLERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAGuildSetAccountRoleResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_OTHER_LEADER', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_TOO_MANY_GUILDS', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_GUILD_TOO_MANY_MEMBERS', index=5, number=5,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1712,
  serialized_end=1878,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDSETACCOUNTROLERESPONSE_ERESULT)

_CMSGDOTAGUILDINVITEACCOUNTRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAGuildInviteAccountResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_ALREADY_INVITED', index=3, number=3,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_ALREADY_IN_GUILD', index=4, number=4,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_TOO_MANY_INVITES', index=5, number=5,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_GUILD_TOO_MANY_INVITES', index=6, number=6,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_ACCOUNT_TOO_MANY_GUILDS', index=7, number=7,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=2072,
  serialized_end=2318,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDINVITEACCOUNTRESPONSE_ERESULT)

_CMSGDOTAGUILDCANCELINVITERESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAGuildCancelInviteResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1712,
  serialized_end=1782,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDCANCELINVITERESPONSE_ERESULT)

_CMSGDOTAGUILDUPDATEDETAILSRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAGuildUpdateDetailsResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_NO_PERMISSION', index=2, number=2,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1712,
  serialized_end=1782,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDUPDATEDETAILSRESPONSE_ERESULT)

_CMSGDOTAPARTYSETOPENGUILDRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAPartySetOpenGuildResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1712,
  serialized_end=1757,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAPARTYSETOPENGUILDRESPONSE_ERESULT)

_CMSGDOTAJOINOPENGUILDPARTYRESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAJoinOpenGuildPartyResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='ERROR_UNSPECIFIED', index=1, number=1,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=1712,
  serialized_end=1757,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAJOINOPENGUILDPARTYRESPONSE_ERESULT)

_CMSGDOTAGUILDEDITLOGORESPONSE_ERESULT = _descriptor.EnumDescriptor(
  name='EResult',
  full_name='CMsgDOTAGuildEditLogoResponse.EResult',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SUCCESS', index=0, number=0,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_PERMISSION', index=1, number=1,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOGO_UPLOAD_FAILED', index=2, number=2,
      options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED_ERROR', index=3, number=3,
      options=None,
      type=None),
  ],
  containing_type=None,
  options=None,
  serialized_start=4324,
  serialized_end=4412,
)
_sym_db.RegisterEnumDescriptor(_CMSGDOTAGUILDEDITLOGORESPONSE_ERESULT)


_CMSGDOTAGUILDSDO_MEMBER = _descriptor.Descriptor(
  name='Member',
  full_name='CMsgDOTAGuildSDO.Member',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAGuildSDO.Member.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_joined', full_name='CMsgDOTAGuildSDO.Member.time_joined', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='CMsgDOTAGuildSDO.Member.role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=336,
  serialized_end=399,
)

_CMSGDOTAGUILDSDO_INVITATION = _descriptor.Descriptor(
  name='Invitation',
  full_name='CMsgDOTAGuildSDO.Invitation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAGuildSDO.Invitation.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_sent', full_name='CMsgDOTAGuildSDO.Invitation.time_sent', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id_sender', full_name='CMsgDOTAGuildSDO.Invitation.account_id_sender', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=401,
  serialized_end=479,
)

_CMSGDOTAGUILDSDO = _descriptor.Descriptor(
  name='CMsgDOTAGuildSDO',
  full_name='CMsgDOTAGuildSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildSDO.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTAGuildSDO.name', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTAGuildSDO.tag', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgDOTAGuildSDO.time_created', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_disbanded', full_name='CMsgDOTAGuildSDO.time_disbanded', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAGuildSDO.logo', index=5,
      number=6, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTAGuildSDO.base_logo', index=6,
      number=7, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTAGuildSDO.banner_logo', index=7,
      number=8, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='members', full_name='CMsgDOTAGuildSDO.members', index=8,
      number=9, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invitations', full_name='CMsgDOTAGuildSDO.invitations', index=9,
      number=10, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgDOTAGuildSDO.message', index=10,
      number=11, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='incremental', full_name='CMsgDOTAGuildSDO.incremental', index=11,
      number=12, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGUILDSDO_MEMBER, _CMSGDOTAGUILDSDO_INVITATION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=39,
  serialized_end=479,
)


_CMSGDOTAGUILDAUDITSDO_ENTRY = _descriptor.Descriptor(
  name='Entry',
  full_name='CMsgDOTAGuildAuditSDO.Entry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='event_index', full_name='CMsgDOTAGuildAuditSDO.Entry.event_index', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='timestamp', full_name='CMsgDOTAGuildAuditSDO.Entry.timestamp', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='action', full_name='CMsgDOTAGuildAuditSDO.Entry.action', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id_requestor', full_name='CMsgDOTAGuildAuditSDO.Entry.account_id_requestor', index=3,
      number=4, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id_target', full_name='CMsgDOTAGuildAuditSDO.Entry.account_id_target', index=4,
      number=5, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_data_a', full_name='CMsgDOTAGuildAuditSDO.Entry.reference_data_a', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='reference_data_b', full_name='CMsgDOTAGuildAuditSDO.Entry.reference_data_b', index=6,
      number=7, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=573,
  serialized_end=745,
)

_CMSGDOTAGUILDAUDITSDO = _descriptor.Descriptor(
  name='CMsgDOTAGuildAuditSDO',
  full_name='CMsgDOTAGuildAuditSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildAuditSDO.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='entries', full_name='CMsgDOTAGuildAuditSDO.entries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGUILDAUDITSDO_ENTRY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=482,
  serialized_end=745,
)


_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_MEMBERSHIP = _descriptor.Descriptor(
  name='Membership',
  full_name='CMsgDOTAAccountGuildMembershipsSDO.Membership',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAAccountGuildMembershipsSDO.Membership.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='role', full_name='CMsgDOTAAccountGuildMembershipsSDO.Membership.role', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=944,
  serialized_end=988,
)

_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_INVITATION = _descriptor.Descriptor(
  name='Invitation',
  full_name='CMsgDOTAAccountGuildMembershipsSDO.Invitation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAAccountGuildMembershipsSDO.Invitation.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_sent', full_name='CMsgDOTAAccountGuildMembershipsSDO.Invitation.time_sent', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='account_id_sender', full_name='CMsgDOTAAccountGuildMembershipsSDO.Invitation.account_id_sender', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=990,
  serialized_end=1066,
)

_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO = _descriptor.Descriptor(
  name='CMsgDOTAAccountGuildMembershipsSDO',
  full_name='CMsgDOTAAccountGuildMembershipsSDO',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='account_id', full_name='CMsgDOTAAccountGuildMembershipsSDO.account_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='memberships', full_name='CMsgDOTAAccountGuildMembershipsSDO.memberships', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='invitations', full_name='CMsgDOTAAccountGuildMembershipsSDO.invitations', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_MEMBERSHIP, _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_INVITATION, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=748,
  serialized_end=1066,
)


_CMSGDOTAGUILDCREATEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildCreateRequest',
  full_name='CMsgDOTAGuildCreateRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='CMsgDOTAGuildCreateRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='tag', full_name='CMsgDOTAGuildCreateRequest.tag', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAGuildCreateRequest.logo', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTAGuildCreateRequest.base_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTAGuildCreateRequest.banner_logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1068,
  serialized_end=1177,
)


_CMSGDOTAGUILDCREATERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildCreateResponse',
  full_name='CMsgDOTAGuildCreateResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildCreateResponse.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='errors', full_name='CMsgDOTAGuildCreateResponse.errors', index=1,
      number=2, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDCREATERESPONSE_EERROR,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1180,
  serialized_end=1494,
)


_CMSGDOTAGUILDSETACCOUNTROLEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildSetAccountRoleRequest',
  full_name='CMsgDOTAGuildSetAccountRoleRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildSetAccountRoleRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTAGuildSetAccountRoleRequest.target_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_role', full_name='CMsgDOTAGuildSetAccountRoleRequest.target_role', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1496,
  serialized_end=1598,
)


_CMSGDOTAGUILDSETACCOUNTROLERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildSetAccountRoleResponse',
  full_name='CMsgDOTAGuildSetAccountRoleResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGuildSetAccountRoleResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDSETACCOUNTROLERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1601,
  serialized_end=1878,
)


_CMSGDOTAGUILDINVITEACCOUNTREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildInviteAccountRequest',
  full_name='CMsgDOTAGuildInviteAccountRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildInviteAccountRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTAGuildInviteAccountRequest.target_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1880,
  serialized_end=1960,
)


_CMSGDOTAGUILDINVITEACCOUNTRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildInviteAccountResponse',
  full_name='CMsgDOTAGuildInviteAccountResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGuildInviteAccountResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDINVITEACCOUNTRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1963,
  serialized_end=2318,
)


_CMSGDOTAGUILDCANCELINVITEREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildCancelInviteRequest',
  full_name='CMsgDOTAGuildCancelInviteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildCancelInviteRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='target_account_id', full_name='CMsgDOTAGuildCancelInviteRequest.target_account_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2320,
  serialized_end=2399,
)


_CMSGDOTAGUILDCANCELINVITERESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildCancelInviteResponse',
  full_name='CMsgDOTAGuildCancelInviteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGuildCancelInviteResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDCANCELINVITERESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2402,
  serialized_end=2578,
)


_CMSGDOTAGUILDUPDATEDETAILSREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildUpdateDetailsRequest',
  full_name='CMsgDOTAGuildUpdateDetailsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildUpdateDetailsRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAGuildUpdateDetailsRequest.logo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='base_logo', full_name='CMsgDOTAGuildUpdateDetailsRequest.base_logo', index=2,
      number=3, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='banner_logo', full_name='CMsgDOTAGuildUpdateDetailsRequest.banner_logo', index=3,
      number=4, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2580,
  serialized_end=2687,
)


_CMSGDOTAGUILDUPDATEDETAILSRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildUpdateDetailsResponse',
  full_name='CMsgDOTAGuildUpdateDetailsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGuildUpdateDetailsResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDUPDATEDETAILSRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2690,
  serialized_end=2868,
)


_CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest',
  full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest.guild_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_account_ids', full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest.member_account_ids', index=2,
      number=3, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyRequest.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2871,
  serialized_end=2999,
)


_CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGCToGCUpdateOpenGuildPartyResponse',
  full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='maintain_association', full_name='CMsgDOTAGCToGCUpdateOpenGuildPartyResponse.maintain_association', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3001,
  serialized_end=3075,
)


_CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGCToGCDestroyOpenGuildPartyRequest',
  full_name='CMsgDOTAGCToGCDestroyOpenGuildPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAGCToGCDestroyOpenGuildPartyRequest.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGCToGCDestroyOpenGuildPartyRequest.guild_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3077,
  serialized_end=3157,
)


_CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGCToGCDestroyOpenGuildPartyResponse',
  full_name='CMsgDOTAGCToGCDestroyOpenGuildPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3159,
  serialized_end=3204,
)


_CMSGDOTAPARTYSETOPENGUILDREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAPartySetOpenGuildRequest',
  full_name='CMsgDOTAPartySetOpenGuildRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAPartySetOpenGuildRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgDOTAPartySetOpenGuildRequest.description', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3206,
  serialized_end=3279,
)


_CMSGDOTAPARTYSETOPENGUILDRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAPartySetOpenGuildResponse',
  full_name='CMsgDOTAPartySetOpenGuildResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAPartySetOpenGuildResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAPARTYSETOPENGUILDRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3282,
  serialized_end=3433,
)


_CMSGDOTAJOINOPENGUILDPARTYREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAJoinOpenGuildPartyRequest',
  full_name='CMsgDOTAJoinOpenGuildPartyRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAJoinOpenGuildPartyRequest.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3435,
  serialized_end=3488,
)


_CMSGDOTAJOINOPENGUILDPARTYRESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAJoinOpenGuildPartyResponse',
  full_name='CMsgDOTAJoinOpenGuildPartyResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAJoinOpenGuildPartyResponse.result', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAJOINOPENGUILDPARTYRESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3491,
  serialized_end=3644,
)


_CMSGDOTAGUILDOPENPARTYREFRESH_OPENPARTY = _descriptor.Descriptor(
  name='OpenParty',
  full_name='CMsgDOTAGuildOpenPartyRefresh.OpenParty',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='party_id', full_name='CMsgDOTAGuildOpenPartyRefresh.OpenParty.party_id', index=0,
      number=1, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_account_ids', full_name='CMsgDOTAGuildOpenPartyRefresh.OpenParty.member_account_ids', index=1,
      number=2, type=13, cpp_type=3, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='time_created', full_name='CMsgDOTAGuildOpenPartyRefresh.OpenParty.time_created', index=2,
      number=3, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='description', full_name='CMsgDOTAGuildOpenPartyRefresh.OpenParty.description', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3762,
  serialized_end=3862,
)

_CMSGDOTAGUILDOPENPARTYREFRESH = _descriptor.Descriptor(
  name='CMsgDOTAGuildOpenPartyRefresh',
  full_name='CMsgDOTAGuildOpenPartyRefresh',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildOpenPartyRefresh.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='open_parties', full_name='CMsgDOTAGuildOpenPartyRefresh.open_parties', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[_CMSGDOTAGUILDOPENPARTYREFRESH_OPENPARTY, ],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3647,
  serialized_end=3862,
)


_CMSGDOTAREQUESTGUILDDATA = _descriptor.Descriptor(
  name='CMsgDOTARequestGuildData',
  full_name='CMsgDOTARequestGuildData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3864,
  serialized_end=3890,
)


_CMSGDOTAGUILDINVITEDATA = _descriptor.Descriptor(
  name='CMsgDOTAGuildInviteData',
  full_name='CMsgDOTAGuildInviteData',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='invited_to_guild', full_name='CMsgDOTAGuildInviteData.invited_to_guild', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildInviteData.guild_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_name', full_name='CMsgDOTAGuildInviteData.guild_name', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_tag', full_name='CMsgDOTAGuildInviteData.guild_tag', index=3,
      number=4, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAGuildInviteData.logo', index=4,
      number=5, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inviter', full_name='CMsgDOTAGuildInviteData.inviter', index=5,
      number=6, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='inviter_name', full_name='CMsgDOTAGuildInviteData.inviter_name', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='member_count', full_name='CMsgDOTAGuildInviteData.member_count', index=7,
      number=8, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3893,
  serialized_end=4076,
)


_CMSGDOTAGUILDUPDATEMESSAGE = _descriptor.Descriptor(
  name='CMsgDOTAGuildUpdateMessage',
  full_name='CMsgDOTAGuildUpdateMessage',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='message', full_name='CMsgDOTAGuildUpdateMessage.message', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildUpdateMessage.guild_id', index=1,
      number=2, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4078,
  serialized_end=4141,
)


_CMSGDOTAGUILDEDITLOGOREQUEST = _descriptor.Descriptor(
  name='CMsgDOTAGuildEditLogoRequest',
  full_name='CMsgDOTAGuildEditLogoRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildEditLogoRequest.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='logo', full_name='CMsgDOTAGuildEditLogoRequest.logo', index=1,
      number=2, type=4, cpp_type=4, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4143,
  serialized_end=4205,
)


_CMSGDOTAGUILDEDITLOGORESPONSE = _descriptor.Descriptor(
  name='CMsgDOTAGuildEditLogoResponse',
  full_name='CMsgDOTAGuildEditLogoResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='guild_id', full_name='CMsgDOTAGuildEditLogoResponse.guild_id', index=0,
      number=1, type=13, cpp_type=3, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
    _descriptor.FieldDescriptor(
      name='result', full_name='CMsgDOTAGuildEditLogoResponse.result', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=True, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      options=None),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _CMSGDOTAGUILDEDITLOGORESPONSE_ERESULT,
  ],
  options=None,
  is_extendable=False,
  syntax='proto2',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4208,
  serialized_end=4412,
)

_CMSGDOTAGUILDSDO_MEMBER.containing_type = _CMSGDOTAGUILDSDO
_CMSGDOTAGUILDSDO_INVITATION.containing_type = _CMSGDOTAGUILDSDO
_CMSGDOTAGUILDSDO.fields_by_name['members'].message_type = _CMSGDOTAGUILDSDO_MEMBER
_CMSGDOTAGUILDSDO.fields_by_name['invitations'].message_type = _CMSGDOTAGUILDSDO_INVITATION
_CMSGDOTAGUILDAUDITSDO_ENTRY.containing_type = _CMSGDOTAGUILDAUDITSDO
_CMSGDOTAGUILDAUDITSDO.fields_by_name['entries'].message_type = _CMSGDOTAGUILDAUDITSDO_ENTRY
_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_MEMBERSHIP.containing_type = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO
_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_INVITATION.containing_type = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO
_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO.fields_by_name['memberships'].message_type = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_MEMBERSHIP
_CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO.fields_by_name['invitations'].message_type = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_INVITATION
_CMSGDOTAGUILDCREATERESPONSE.fields_by_name['errors'].enum_type = _CMSGDOTAGUILDCREATERESPONSE_EERROR
_CMSGDOTAGUILDCREATERESPONSE_EERROR.containing_type = _CMSGDOTAGUILDCREATERESPONSE
_CMSGDOTAGUILDSETACCOUNTROLERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGUILDSETACCOUNTROLERESPONSE_ERESULT
_CMSGDOTAGUILDSETACCOUNTROLERESPONSE_ERESULT.containing_type = _CMSGDOTAGUILDSETACCOUNTROLERESPONSE
_CMSGDOTAGUILDINVITEACCOUNTRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGUILDINVITEACCOUNTRESPONSE_ERESULT
_CMSGDOTAGUILDINVITEACCOUNTRESPONSE_ERESULT.containing_type = _CMSGDOTAGUILDINVITEACCOUNTRESPONSE
_CMSGDOTAGUILDCANCELINVITERESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGUILDCANCELINVITERESPONSE_ERESULT
_CMSGDOTAGUILDCANCELINVITERESPONSE_ERESULT.containing_type = _CMSGDOTAGUILDCANCELINVITERESPONSE
_CMSGDOTAGUILDUPDATEDETAILSRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGUILDUPDATEDETAILSRESPONSE_ERESULT
_CMSGDOTAGUILDUPDATEDETAILSRESPONSE_ERESULT.containing_type = _CMSGDOTAGUILDUPDATEDETAILSRESPONSE
_CMSGDOTAPARTYSETOPENGUILDRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAPARTYSETOPENGUILDRESPONSE_ERESULT
_CMSGDOTAPARTYSETOPENGUILDRESPONSE_ERESULT.containing_type = _CMSGDOTAPARTYSETOPENGUILDRESPONSE
_CMSGDOTAJOINOPENGUILDPARTYRESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAJOINOPENGUILDPARTYRESPONSE_ERESULT
_CMSGDOTAJOINOPENGUILDPARTYRESPONSE_ERESULT.containing_type = _CMSGDOTAJOINOPENGUILDPARTYRESPONSE
_CMSGDOTAGUILDOPENPARTYREFRESH_OPENPARTY.containing_type = _CMSGDOTAGUILDOPENPARTYREFRESH
_CMSGDOTAGUILDOPENPARTYREFRESH.fields_by_name['open_parties'].message_type = _CMSGDOTAGUILDOPENPARTYREFRESH_OPENPARTY
_CMSGDOTAGUILDEDITLOGORESPONSE.fields_by_name['result'].enum_type = _CMSGDOTAGUILDEDITLOGORESPONSE_ERESULT
_CMSGDOTAGUILDEDITLOGORESPONSE_ERESULT.containing_type = _CMSGDOTAGUILDEDITLOGORESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildSDO'] = _CMSGDOTAGUILDSDO
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildAuditSDO'] = _CMSGDOTAGUILDAUDITSDO
DESCRIPTOR.message_types_by_name['CMsgDOTAAccountGuildMembershipsSDO'] = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildCreateRequest'] = _CMSGDOTAGUILDCREATEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildCreateResponse'] = _CMSGDOTAGUILDCREATERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildSetAccountRoleRequest'] = _CMSGDOTAGUILDSETACCOUNTROLEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildSetAccountRoleResponse'] = _CMSGDOTAGUILDSETACCOUNTROLERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildInviteAccountRequest'] = _CMSGDOTAGUILDINVITEACCOUNTREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildInviteAccountResponse'] = _CMSGDOTAGUILDINVITEACCOUNTRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildCancelInviteRequest'] = _CMSGDOTAGUILDCANCELINVITEREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildCancelInviteResponse'] = _CMSGDOTAGUILDCANCELINVITERESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildUpdateDetailsRequest'] = _CMSGDOTAGUILDUPDATEDETAILSREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildUpdateDetailsResponse'] = _CMSGDOTAGUILDUPDATEDETAILSRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGCToGCUpdateOpenGuildPartyRequest'] = _CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGCToGCUpdateOpenGuildPartyResponse'] = _CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGCToGCDestroyOpenGuildPartyRequest'] = _CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGCToGCDestroyOpenGuildPartyResponse'] = _CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAPartySetOpenGuildRequest'] = _CMSGDOTAPARTYSETOPENGUILDREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAPartySetOpenGuildResponse'] = _CMSGDOTAPARTYSETOPENGUILDRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAJoinOpenGuildPartyRequest'] = _CMSGDOTAJOINOPENGUILDPARTYREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAJoinOpenGuildPartyResponse'] = _CMSGDOTAJOINOPENGUILDPARTYRESPONSE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildOpenPartyRefresh'] = _CMSGDOTAGUILDOPENPARTYREFRESH
DESCRIPTOR.message_types_by_name['CMsgDOTARequestGuildData'] = _CMSGDOTAREQUESTGUILDDATA
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildInviteData'] = _CMSGDOTAGUILDINVITEDATA
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildUpdateMessage'] = _CMSGDOTAGUILDUPDATEMESSAGE
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildEditLogoRequest'] = _CMSGDOTAGUILDEDITLOGOREQUEST
DESCRIPTOR.message_types_by_name['CMsgDOTAGuildEditLogoResponse'] = _CMSGDOTAGUILDEDITLOGORESPONSE

CMsgDOTAGuildSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildSDO', (_message.Message,), dict(

  Member = _reflection.GeneratedProtocolMessageType('Member', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGUILDSDO_MEMBER,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGuildSDO.Member)
    ))
  ,

  Invitation = _reflection.GeneratedProtocolMessageType('Invitation', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGUILDSDO_INVITATION,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGuildSDO.Invitation)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGUILDSDO,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildSDO)
_sym_db.RegisterMessage(CMsgDOTAGuildSDO.Member)
_sym_db.RegisterMessage(CMsgDOTAGuildSDO.Invitation)

CMsgDOTAGuildAuditSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildAuditSDO', (_message.Message,), dict(

  Entry = _reflection.GeneratedProtocolMessageType('Entry', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGUILDAUDITSDO_ENTRY,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGuildAuditSDO.Entry)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGUILDAUDITSDO,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildAuditSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildAuditSDO)
_sym_db.RegisterMessage(CMsgDOTAGuildAuditSDO.Entry)

CMsgDOTAAccountGuildMembershipsSDO = _reflection.GeneratedProtocolMessageType('CMsgDOTAAccountGuildMembershipsSDO', (_message.Message,), dict(

  Membership = _reflection.GeneratedProtocolMessageType('Membership', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_MEMBERSHIP,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAAccountGuildMembershipsSDO.Membership)
    ))
  ,

  Invitation = _reflection.GeneratedProtocolMessageType('Invitation', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO_INVITATION,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAAccountGuildMembershipsSDO.Invitation)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAACCOUNTGUILDMEMBERSHIPSSDO,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAAccountGuildMembershipsSDO)
  ))
_sym_db.RegisterMessage(CMsgDOTAAccountGuildMembershipsSDO)
_sym_db.RegisterMessage(CMsgDOTAAccountGuildMembershipsSDO.Membership)
_sym_db.RegisterMessage(CMsgDOTAAccountGuildMembershipsSDO.Invitation)

CMsgDOTAGuildCreateRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildCreateRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDCREATEREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildCreateRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildCreateRequest)

CMsgDOTAGuildCreateResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildCreateResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDCREATERESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildCreateResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildCreateResponse)

CMsgDOTAGuildSetAccountRoleRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildSetAccountRoleRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDSETACCOUNTROLEREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildSetAccountRoleRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildSetAccountRoleRequest)

CMsgDOTAGuildSetAccountRoleResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildSetAccountRoleResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDSETACCOUNTROLERESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildSetAccountRoleResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildSetAccountRoleResponse)

CMsgDOTAGuildInviteAccountRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildInviteAccountRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDINVITEACCOUNTREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildInviteAccountRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildInviteAccountRequest)

CMsgDOTAGuildInviteAccountResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildInviteAccountResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDINVITEACCOUNTRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildInviteAccountResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildInviteAccountResponse)

CMsgDOTAGuildCancelInviteRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildCancelInviteRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDCANCELINVITEREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildCancelInviteRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildCancelInviteRequest)

CMsgDOTAGuildCancelInviteResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildCancelInviteResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDCANCELINVITERESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildCancelInviteResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildCancelInviteResponse)

CMsgDOTAGuildUpdateDetailsRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildUpdateDetailsRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDUPDATEDETAILSREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildUpdateDetailsRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildUpdateDetailsRequest)

CMsgDOTAGuildUpdateDetailsResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildUpdateDetailsResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDUPDATEDETAILSRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildUpdateDetailsResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildUpdateDetailsResponse)

CMsgDOTAGCToGCUpdateOpenGuildPartyRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGCToGCUpdateOpenGuildPartyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGCToGCUpdateOpenGuildPartyRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGCToGCUpdateOpenGuildPartyRequest)

CMsgDOTAGCToGCUpdateOpenGuildPartyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGCToGCUpdateOpenGuildPartyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGCTOGCUPDATEOPENGUILDPARTYRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGCToGCUpdateOpenGuildPartyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGCToGCUpdateOpenGuildPartyResponse)

CMsgDOTAGCToGCDestroyOpenGuildPartyRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGCToGCDestroyOpenGuildPartyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGCToGCDestroyOpenGuildPartyRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGCToGCDestroyOpenGuildPartyRequest)

CMsgDOTAGCToGCDestroyOpenGuildPartyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGCToGCDestroyOpenGuildPartyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGCTOGCDESTROYOPENGUILDPARTYRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGCToGCDestroyOpenGuildPartyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGCToGCDestroyOpenGuildPartyResponse)

CMsgDOTAPartySetOpenGuildRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAPartySetOpenGuildRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPARTYSETOPENGUILDREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPartySetOpenGuildRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAPartySetOpenGuildRequest)

CMsgDOTAPartySetOpenGuildResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAPartySetOpenGuildResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAPARTYSETOPENGUILDRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAPartySetOpenGuildResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAPartySetOpenGuildResponse)

CMsgDOTAJoinOpenGuildPartyRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAJoinOpenGuildPartyRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAJOINOPENGUILDPARTYREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAJoinOpenGuildPartyRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAJoinOpenGuildPartyRequest)

CMsgDOTAJoinOpenGuildPartyResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAJoinOpenGuildPartyResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAJOINOPENGUILDPARTYRESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAJoinOpenGuildPartyResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAJoinOpenGuildPartyResponse)

CMsgDOTAGuildOpenPartyRefresh = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildOpenPartyRefresh', (_message.Message,), dict(

  OpenParty = _reflection.GeneratedProtocolMessageType('OpenParty', (_message.Message,), dict(
    DESCRIPTOR = _CMSGDOTAGUILDOPENPARTYREFRESH_OPENPARTY,
    __module__ = 'dota_gcmessages_client_guild_pb2'
    # @@protoc_insertion_point(class_scope:CMsgDOTAGuildOpenPartyRefresh.OpenParty)
    ))
  ,
  DESCRIPTOR = _CMSGDOTAGUILDOPENPARTYREFRESH,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildOpenPartyRefresh)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildOpenPartyRefresh)
_sym_db.RegisterMessage(CMsgDOTAGuildOpenPartyRefresh.OpenParty)

CMsgDOTARequestGuildData = _reflection.GeneratedProtocolMessageType('CMsgDOTARequestGuildData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAREQUESTGUILDDATA,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTARequestGuildData)
  ))
_sym_db.RegisterMessage(CMsgDOTARequestGuildData)

CMsgDOTAGuildInviteData = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildInviteData', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDINVITEDATA,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildInviteData)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildInviteData)

CMsgDOTAGuildUpdateMessage = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildUpdateMessage', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDUPDATEMESSAGE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildUpdateMessage)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildUpdateMessage)

CMsgDOTAGuildEditLogoRequest = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildEditLogoRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDEDITLOGOREQUEST,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildEditLogoRequest)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildEditLogoRequest)

CMsgDOTAGuildEditLogoResponse = _reflection.GeneratedProtocolMessageType('CMsgDOTAGuildEditLogoResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMSGDOTAGUILDEDITLOGORESPONSE,
  __module__ = 'dota_gcmessages_client_guild_pb2'
  # @@protoc_insertion_point(class_scope:CMsgDOTAGuildEditLogoResponse)
  ))
_sym_db.RegisterMessage(CMsgDOTAGuildEditLogoResponse)


DESCRIPTOR.has_options = True
DESCRIPTOR._options = _descriptor._ParseOptions(descriptor_pb2.FileOptions(), _b('H\001\220\001\000'))
# @@protoc_insertion_point(module_scope)
